@@ -171,8 +171,7 @@
 /* We want our int32 types to be int, not long */
 #define STDINT_LONG32			0
 
-/* We don't support DWARF2 */
-#undef  PREFERRED_DEBUGGING_TYPE
-#define PREFERRED_DEBUGGING_TYPE NO_DEBUG
+/* We want DWARF2 debugging */
+#define DWARF2_DEBUGGING_INFO 1
 
 #endif /* !XTENSA_CONFIG_H */
